#!/bin/sh
# Requirements
#   * Add the default user to sudoers without password and to group sudo
#   * Remember to set GRUB_DEFAULT to saved

datadir=../data
bindir=../bin
isodir=$datadir/iso/ubuntu
customdir=$datadir/custom-installation
diskimage=$isodir/i386.tar.xz
wubiexe=$isodir/wubi.exe
hostdev=/dev/sda3
mntdir=/tmp/wubi/target
rootdir=/tmp/wubi/rootdisk
wubidir=$mntdir/wubi
wubibin=$wubidir/bin
wubidata=$wubidir/data/iso/ubuntu
wubirun=$wubidir/run/latest

usage() {
    cat <<EOF
Usage: $(basename $0) COMMAND [OPTIONS]
Commands:
    * start [i386|amd64]  : Start the test
    * updateroot          : Modify root.disk
    * report              : Report the final results to Jenkins
EOF

exit 0
}

start() {
    # Init the test and copy the files to be tested to the target

    diskimage=$isodir/$1.tar.xz

    if [ ! -f "$diskimage" ]; then
        echo "Disk image doesn't exist: $diskimage"
        exit 1
    fi
    mount_target
    #sudo mkdir -p $wubidir
    sudo mkdir -p $wubibin $wubirun $wubidata

    sudo cp -af $diskimage $wubiexe $wubidata
    sudo cp -af $bindir/functions $bindir/wubi-test.sh $wubibin

    #sudo echo "
    #    --dimagepath=C:\\wubi\\$(basename $diskimage) --skipmd5check --noninteractive" >$wubidir/wubi.bat
    sudo echo "@echo off

C:
chdir C:\wubi

\\cygwin\\bin\\bash.exe --login -c \"cd /cygdrive/c/wubi/; ./bin/wubi-test.sh -r --dimagepath=data/iso/ubuntu/$(basename $diskimage)\" 
    " | todos > $wubibin/wubi.bat

    reboot_once
}

update_root() {
    # update the root disk
    mount_target

    mkdir -p $rootdir
    mountpoint -q $rootdir || sudo mount -t ext3 -o loop $mntdir/ubuntu/disks/root.disk $rootdir

    # Copy the content of custom-installation directory
    sudo cp -af $customdir/target-override/* $rootdir/
    sudo umount $rootdir
    reboot_once
}

report_results() {
    # Report the results to jenkins
    echo "reporting to jenkins"
    mountpoint -q $rootdir || sudo mount -t ext3 -o loop $mntdir/ubuntu/disks/root.disk $rootdir

    # Retrieve the results from the host
    # TODO: Change the test script to copy the results on the host

    sudo umount $rootdir
}

reboot_once() {
    # Reboot once to windows
    winentry="$(grep Window /boot/grub/grub.cfg |cut -d\" -f2)"
    sudo grub-set-default 0
    sudo grub-reboot "$winentry"
}

mount_target() {
    # TODO Check that it is not already mounted
    # If it is reuse the mount point 
    mkdir -p $mntdir
    mountpoint -q $mntdir || sudo mount -t ntfs $hostdev $mntdir
}


case "$1" in
    start)
        start $2;;
    updateroot)
        update_root;;
    report)
        report_results;;
    *) usage;;
esac

