#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#

import logging
import os.path
import unittest
import lsb_release
import subprocess

logging.basicConfig(level=logging.INFO)

def cmd(command, input = None, stderr = subprocess.STDOUT, stdout = subprocess.PIPE, stdin = None):
    '''Try to execute given command (array) and return its stdout, or return
    a textual error if it failed.'''

    try:
        sp = subprocess.Popen(command, stdin=stdin, stdout=stdout, stderr=stderr, close_fds=True)
    except OSError, e:
        return [127, str(e)]

    out, outerr = sp.communicate(input)
    # Handle redirection of stdout
    if out == None:
        out = ''
    # Handle redirection of stderr
    if outerr == None:
        outerr = ''
    return [sp.returncode,out+outerr]

class DefaultTest(unittest.TestCase):

    mount_point = "/host"
    wubidir = os.path.join(mount_point, 'ubuntu')
    distinfo = lsb_release.get_distro_information()
    pkg_test = 'hello' # Example package used by the apt test

    def test_01_host_is_mounted(self):
        self.assertTrue(os.path.ismount(self.mount_point))

    def test_02_read_write(self):
        t_fh = open(os.path.join(self.mount_point, 'Temp', 'a'), 'w')
        self.assertNotEqual(t_fh, None)
        self.assertEqual(t_fh.write('a'), None)
        self.assertEqual(t_fh.close(), None)

    def test_03_wubi_dir_structure(self):
        wubi_filelist = (
            '/host/ubuntu/',
            '/host/ubuntu/disks',
            '/host/ubuntu/disks/boot',
            '/host/ubuntu/disks/boot/grub',
            '/host/ubuntu/disks/root.disk',
            '/host/ubuntu/disks/swap.disk',
            '/host/ubuntu/install',
            '/host/ubuntu/Ubuntu.ico',
            '/host/ubuntu/uninstall-wubi.exe',
            '/host/ubuntu/winboot',
            '/host/ubuntu/winboot/wubildr',
            '/host/ubuntu/winboot/wubildr-bootstrap.cfg',
            '/host/ubuntu/winboot/wubildr.cfg',
            '/host/ubuntu/winboot/wubildr.mbr',
            '/host/ubuntu/winboot/wubildr.tar'
        )

        for f in wubi_filelist:
            self.assertTrue(os.path.exists(f), "File not found: '%s'" % f)

    def test_04_apt_update(self):
        '''apt-get update'''
        rc, report = cmd(['apt-get', 'update'])
        expected = 0
        result = 'Got exit code %d, expected %d\n' % (rc, expected)
        self.assertEquals(expected, rc, result + report)

    def test_05_apt_install_remove(self):
        '''apt-get install'''
        rc, report = cmd(['apt-get', 'install', '-y', self.pkg_test])
        expected = 0
        result = 'Got exit code %d, expected %d\n' % (rc, expected)
        self.assertEquals(expected, rc, result + report)

        rc, report = cmd(['apt-get', 'remove', '-y', '--purge', self.pkg_test])
        expected = 0
        result = 'Got exit code %d, expected %d\n' % (rc, expected)
        self.assertEquals(expected, rc, result + report)


if __name__ == '__main__':
    unittest.main()

